Controlling WWT from Python
===========================

Once you've `opened up your WWT viewer <opening>`_, you can control nearly every
aspect of it programmatically with pywwt.

.. toctree::
   :maxdepth: 2

   settings
   views
   annotations
   layers
   fov
   shortcuts
   tours
